@@ -6,8 +6,8 @@ class BaseHandler(object):
     """
     Represents a base handler class that handles any request
     """
-    def __call__(self, wbrequest):
-        return wbrequest
+    def __call__(self, wbrequest):  # pragma: no cover
+        raise NotImplementedError('Need to implement in derived class')
 
     def get_wburl_type(self):
         return None
