@@ -25,7 +25,7 @@ class RegexRewriter(object):
 
     @staticmethod
     def archival_rewrite(rewriter):
-        return lambda string: rewriter.rewrite(string, 'mp_')
+        return lambda string: rewriter.rewrite(string)
 
     #@staticmethod
     #def replacer(other):
@@ -90,13 +90,19 @@ class RegexRewriter(object):
 
     @staticmethod
     def parse_rules_from_config(config):
-        def parse_rule(obj):
-            match = obj.get('match')
-            replace = RegexRewriter.format(obj.get('replace', '{0}'))
-            group = obj.get('group', 0)
-            result = (match, replace, group)
-            return result
-        return map(parse_rule, config)
+        def run_parse_rules(rewriter):
+            def parse_rule(obj):
+                match = obj.get('match')
+                if 'rewrite' in obj:
+                    replace = RegexRewriter.archival_rewrite(rewriter)
+                else:
+                    replace = RegexRewriter.format(obj.get('replace', '{0}'))
+                group = obj.get('group', 0)
+                result = (match, replace, group)
+                return result
+            
+            return map(parse_rule, config)
+        return run_parse_rules
 
 
 #=================================================================
@@ -123,7 +129,7 @@ class JSLinkAndLocationRewriter(JSLinkOnlyRewriter):
 
     def __init__(self, rewriter, rules=[], prefix='WB_wombat_'):
         rules = rules + [
-             (r'(?<!/)\blocation\b', RegexRewriter.add_prefix(prefix), 0),
+             (r'(?<!/)\blocation\b(?!\":)', RegexRewriter.add_prefix(prefix), 0),
              (r'(?<=document\.)domain', RegexRewriter.add_prefix(prefix), 0),
              (r'(?<=document\.)referrer', RegexRewriter.add_prefix(prefix), 0),
              (r'(?<=document\.)cookie', RegexRewriter.add_prefix(prefix), 0),
