@@ -15,7 +15,8 @@ from pywb.utils.wbexception import WbException
 #=================================================================
 ArcWarcRecord = collections.namedtuple('ArcWarcRecord',
                                        'format, rec_type, rec_headers, ' +
-                                       'stream, status_headers')
+                                       'stream, status_headers, ' +
+                                       'content_type, length')
 
 
 #=================================================================
@@ -46,8 +47,9 @@ class ArcWarcRecordLoader:
     HTTP_VERBS = ['GET', 'HEAD', 'POST', 'PUT', 'DELETE', 'TRACE',
                   'OPTIONS', 'CONNECT', 'PATCH']
 
-    def __init__(self, loader=None, cookie_maker=None, block_size=8192,
-                 parse_request=False):
+    NON_HTTP_RECORDS = ('warcinfo', 'arc_header', 'metadata', 'resource')
+
+    def __init__(self, loader=None, cookie_maker=None, block_size=8192):
         if not loader:
             loader = BlockLoader(cookie_maker)
 
@@ -59,9 +61,7 @@ class ArcWarcRecordLoader:
         self.warc_parser = StatusAndHeadersParser(self.WARC_TYPES)
         self.http_parser = StatusAndHeadersParser(self.HTTP_TYPES)
 
-        self.parse_request = parse_request
-        if self.parse_request:
-            self.http_req_parser = StatusAndHeadersParser(self.HTTP_VERBS)
+        self.http_req_parser = StatusAndHeadersParser(self.HTTP_VERBS)
 
     def load(self, url, offset, length):
         """ Load a single record from given url at offset with length
@@ -97,76 +97,59 @@ class ArcWarcRecordLoader:
                                                                known_format))
 
         if the_format == 'arc':
-            if rec_headers.get_header('uri').startswith('filedesc://'):
+            uri = rec_headers.get_header('uri')
+            length = rec_headers.get_header('length')
+            content_type = rec_headers.get_header('content-type')
+            sub_len = rec_headers.total_len
+            if uri and uri.startswith('filedesc://'):
                 rec_type = 'arc_header'
-                length = 0
             else:
                 rec_type = 'response'
-                length = rec_headers.get_header('length')
 
         elif the_format == 'warc':
             rec_type = rec_headers.get_header('WARC-Type')
+            uri = rec_headers.get_header('WARC-Target-URI')
             length = rec_headers.get_header('Content-Length')
+            content_type = rec_headers.get_header('Content-Type')
+            sub_len = 0
 
         is_err = False
 
         try:
-            length = int(length)
+            length = int(length) - sub_len
             if length < 0:
                 is_err = True
         except ValueError:
             is_err = True
 
-        # ================================================================
-        # handle different types of records
-
         # err condition
         if is_err:
-            status_headers = StatusAndHeaders('-', [])
             length = 0
-        # special case: empty w/arc record (hopefully a revisit)
-        elif length == 0:
-            status_headers = StatusAndHeaders('204 No Content', [])
+        # limit stream to the length for all valid records
+        stream = LimitReader.wrap_stream(stream, length)
 
-        # special case: warc records that are not expected to have http headers
-        # attempt to add 200 status and content-type
-        elif rec_type == 'metadata' or rec_type == 'resource':
-            content_type = [('Content-Type',
-                            rec_headers.get_header('Content-Type'))]
+        # if empty record (error or otherwise) set status to -
+        if length == 0:
+            status_headers = StatusAndHeaders('- None', [])
 
-            status_headers = StatusAndHeaders('200 OK', content_type)
-
-        elif (rec_type == 'warcinfo' or
-              rec_type == 'arc_header'):
-            # not parsing these for now
-            status_headers = StatusAndHeaders('204 No Content', [])
-
-        elif (rec_type == 'request'):
-            if self.parse_request:
-                status_headers = self.http_req_parser.parse(stream)
-            else:
-                status_headers = StatusAndHeaders('204 No Content', [])
-
-        # special case: http 0.9 response, no status or headers
-        #elif rec_type == 'response':
-        #    content_type = rec_headers.get_header('Content-Type')
-        #    if content_type and (';version=0.9' in content_type):
-        #        status_headers = StatusAndHeaders('200 OK', [])
-
-        # response record: parse HTTP status and headers!
-        else:
-            #(statusline, http_headers) = self.parse_http_headers(stream)
+        # response record or non-empty revisit: parse HTTP status and headers!
+        elif (rec_type in ('response', 'revisit') and
+              not uri.startswith(('dns:', 'whois:'))):
             status_headers = self.http_parser.parse(stream)
 
-        # limit the stream to the remainder, if >0
-        # should always be valid, but just in case, still stream if
-        # content-length was not set
-        remains = length - status_headers.total_len
-        if remains >= 0:
-            stream = LimitReader.wrap_stream(stream, remains)
+        # request record: parse request
+        elif ((rec_type == 'request') and
+              not uri.startswith(('dns:', 'whois:'))):
+            status_headers = self.http_req_parser.parse(stream)
+
+        # everything else: create a no-status entry, set content-type
+        else:
+            content_type_header = [('Content-Type', content_type)]
+            status_headers = StatusAndHeaders('- OK', content_type_header)
 
         return ArcWarcRecord(the_format, rec_type,
-                             rec_headers, stream, status_headers)
+                             rec_headers, stream, status_headers,
+                             content_type, length)
 
     def _detect_type_load_headers(self, stream,
                                   statusline=None, known_format=None):
@@ -196,7 +179,7 @@ class ArcWarcRecordLoader:
             return 'arc', rec_headers
         except StatusAndHeadersParserException as se:
             if known_format == 'arc':
-                msg = 'Invalid WARC record, first line: '
+                msg = 'Invalid ARC record, first line: '
             else:
                 msg = 'Unknown archive format, first line: '
             raise ArchiveLoadFailed(msg + str(se.statusline))
@@ -208,16 +191,15 @@ class ARCHeadersParser:
         self.headernames = headernames
 
     def parse(self, stream, headerline=None):
-
         total_read = 0
 
         # if headerline passed in, use that
         if headerline is None:
             headerline = stream.readline()
 
-        total_read = len(headerline)
+        header_len = len(headerline)
 
-        if total_read == 0:
+        if header_len == 0:
             raise EOFError()
 
         headerline = headerline.rstrip()
@@ -226,8 +208,10 @@ class ARCHeadersParser:
 
         # if arc header, consume next two lines
         if headerline.startswith('filedesc://'):
-            stream.readline()  # skip version
-            stream.readline()  # skip header spec, use preset one
+            version = stream.readline()  # skip version
+            spec = stream.readline()  # skip header spec, use preset one
+            total_read += len(version)
+            total_read += len(spec)
 
         parts = headerline.split(' ')
 
