@@ -7,7 +7,8 @@ import logging
 
 from os import path
 from itertools import imap
-from jinja2 import Environment, FileSystemLoader, PackageLoader
+from jinja2 import Environment
+from jinja2 import FileSystemLoader, PackageLoader, ChoiceLoader
 
 
 FILTERS = {}
@@ -71,22 +72,28 @@ class J2TemplateView(object):
 
     def __init__(self, filename):
         template_dir, template_file = path.split(filename)
-
         self.template_file = template_file
 
         self.jinja_env = self.make_jinja_env(template_dir)
 
     def make_jinja_env(self, template_dir):
-        if template_dir.startswith('.') or template_dir.startswith('file://'):
-            loader = FileSystemLoader(template_dir)
-        else:
-            loader = PackageLoader(self.env_globals['package'], template_dir)
-
+        loaders = self._make_loaders(template_dir)
+        loader = ChoiceLoader(loaders)
+        
         jinja_env = Environment(loader=loader, trim_blocks=True)
         jinja_env.filters.update(FILTERS)
         jinja_env.globals.update(self.env_globals)
         return jinja_env
 
+    def _make_loaders(self, template_dir):
+        loaders = []
+        loaders.append(FileSystemLoader(template_dir))
+        # add relative and absolute path loaders for banner support
+        loaders.append(FileSystemLoader('.'))
+        loaders.append(FileSystemLoader('/'))
+        loaders.append(PackageLoader(self.env_globals['package'], template_dir))
+        return loaders
+
     def render_to_string(self, **kwargs):
         template = self.jinja_env.get_template(self.template_file)
 
@@ -124,29 +131,35 @@ class HeadInsertView(J2TemplateView):
     def create_insert_func(self, wbrequest,
                            include_ts=True):
 
-        canon_url = wbrequest.wb_prefix + wbrequest.wb_url.to_str(mod='')
+        top_url = wbrequest.wb_prefix
+        top_url += wbrequest.wb_url.to_str(mod=wbrequest.final_mod)
+
         include_wombat = not wbrequest.wb_url.is_banner_only
 
         def make_head_insert(rule, cdx):
             return (self.render_to_string(wbrequest=wbrequest,
                                           cdx=cdx,
-                                          canon_url=canon_url,
+                                          top_url=top_url,
                                           include_ts=include_ts,
                                           include_wombat=include_wombat,
+                                          banner_html=self.banner_html,
                                           rule=rule))
         return make_head_insert
 
-    @staticmethod
-    def create_template(filename, desc=''):
-        return J2TemplateView.create_template(filename, desc,
-                                              HeadInsertView)
-
     @staticmethod
     def init_from_config(config):
         view = config.get('head_insert_view')
         if not view:
             html = config.get('head_insert_html', 'ui/head_insert.html')
-            view = HeadInsertView.create_template(html, 'Head Insert')
+
+            if html:
+                banner_html = config.get('banner_html', 'banner.html')
+                view = HeadInsertView(html)
+                logging.debug('Adding HeadInsert: {0}, Banner {1}'.
+                              format(html, banner_html))
+
+                view.banner_html = banner_html
+
         return view
 
 
